.. SPDX-FileCopyrightText: 2022 geisserml <geisserml@gmail.com>
.. SPDX-License-Identifier: CC-BY-4.0

pypdfium2
=========

.. _PDFium: https://developers.foxit.com/resources/pdf-sdk/c_api_reference_pdfium/group___f_p_d_f_i_u_m.html

| Welcome to the documentation for the support model of pypdfium2.
| Concerning the low-level API, please also refer to the documentation for `PDFium`_ and :mod:`ctypes`.


.. toctree::
   :maxdepth: 2
   :caption: Usage
   
   python_api
   shell_api
   planned_changes

.. toctree::
   :maxdepth: 1
   :caption: Changelog
   
   changelog


Indices
-------

* :ref:`genindex`
* :ref:`modindex`
